@@ -97,6 +97,7 @@ class GConfHandler(object):
         notify_add(KEY('/general/compat_delete'), self.delete_changed)
         notify_add(KEY('/general/custom_command_file'), self.custom_command_file_changed)
         notify_add(KEY('/general/max_tab_name_length'), self.max_tab_name_length_changed)
+        notify_add(KEY('/general/abbreviate_tab_names'), self.abbreviate_tab_names_changed)
 
     def custom_command_file_changed(self, client, connection_id, entry, data):
         self.guake.load_custom_commands()
@@ -145,6 +146,8 @@ class GConfHandler(object):
         be called and will call the move function in guake.
         """
         self.guake.set_final_window_rect()
+        self.guake.set_tab_position()
+        self.guake.force_move_if_shown()
 
     def size_changed(self, client, connection_id, entry, data):
         """If the gconf var window_height or window_width are changed,
@@ -356,21 +359,15 @@ class GConfHandler(object):
         if self.guake.notebook.get_current_terminal().get_window_title() is None:
             return
 
-        max_name_length = client.get_int(KEY("/general/max_tab_name_length"))
+        self.guake.recompute_tabs_titles()
 
-        if max_name_length == 0:
-            max_name_length = None
-
-        vte_titles_on = client.get_bool(KEY("/general/use_vte_titles"))
-        tab_name = self.guake.notebook.get_current_terminal(
-        ).get_window_title() if vte_titles_on else _("Terminal")
-        for tab in self.guake.tabs.get_children():
-            if not getattr(tab, 'custom_label_set', False):
-                tab.set_label(tab_name[:max_name_length])
-            else:
-                # retrieve the custom tab name to restore it
-                tab_custom_name = getattr(tab, 'custom_label_text', False)
-                tab.set_label(tab_custom_name[:max_name_length])
+    def abbreviate_tab_names_changed(self, client, connection_id, entry, data):
+        """If the gconf var abbreviate_tab_names be changed, this method will
+        be called and will update tab names.
+        """
+        abbreviate_tab_names = client.get_bool(KEY('/general/abbreviate_tab_names'))
+        self.guake.abbreviate = abbreviate_tab_names and self.guake.is_tabs_scrollbar_visible()
+        self.guake.recompute_tabs_titles()
 
 
 class GConfKeyHandler(object):
