@@ -171,6 +171,8 @@ class Guake(SimpleGladeApp):
         self.forceHide = False
         self.preventHide = False
 
+        self.custom_command_menuitem = None
+
         # trayicon! Using SVG handles better different OS trays
         img = pixmapfile('guake-tray.svg')
 
@@ -292,6 +294,26 @@ class Guake(SimpleGladeApp):
 
         evtbox.connect('scroll-event', scroll_manager)
 
+        self.abbreviate = False
+        self.was_deleted_tab = False
+
+        def tabs_scrollbar_hide(hscrollbar):
+            self.get_widget('event-tabs').set_property('height_request', 10)
+            if self.abbreviate and self.was_deleted_tab:
+                self.was_deleted_tab = False
+                self.abbreviate = False
+                self.recompute_tabs_titles()
+
+        def tabs_scrollbar_show(hscrollbar):
+            self.get_widget('event-tabs').set_property('height_request', -1)
+            if self.client.get_bool(KEY("/general/abbreviate_tab_names")):
+                self.abbreviate = True
+                self.recompute_tabs_titles()
+
+        tabs_scrollbar = self.get_widget('tabs-scrolledwindow').get_hscrollbar()
+        tabs_scrollbar.connect('hide', tabs_scrollbar_hide)
+        tabs_scrollbar.connect('show', tabs_scrollbar_show)
+
         # Flag to prevent guake hide when window_losefocus is true and
         # user tries to use the context menu.
         self.showing_context_menu = False
@@ -361,17 +383,17 @@ class Guake(SimpleGladeApp):
 
     # load the custom commands infrastucture
     def load_custom_commands(self):
-        if hasattr(self, 'custom_command_menuitem') and self.custom_command_menuitem:
-            self.get_widget(
-                'context-menu').remove(self.custom_command_menuitem)
-        menu = gtk.MenuItem("Custom Commands")
+        if self.custom_command_menuitem:
+            self.get_widget('context-menu').remove(self.custom_command_menuitem)
         custom_commands_menu = gtk.Menu()
-        self.get_custom_commands(custom_commands_menu)
+        if not self.get_custom_commands(custom_commands_menu):
+            return
+        menu = gtk.MenuItem("Custom Commands")
         menu.set_submenu(custom_commands_menu)
         menu.show()
-        self.get_widget('context-menu').insert(menu,
-                                               self.context_menu_get_insert_pos())
         self.custom_command_menuitem = menu
+        context_menu = self.get_widget('context-menu')
+        context_menu.insert(self.custom_command_menuitem, self.context_menu_get_insert_pos())
 
     # returns position where the custom cmd must be placed on the context-menu
     def context_menu_get_insert_pos(self):
@@ -384,26 +406,28 @@ class Guake(SimpleGladeApp):
     def get_custom_commands(self, menu):
         custom_command_file_path = self.client.get_string(KEY('/general/custom_command_file'))
         if not custom_command_file_path:
-            return
+            return False
         file_name = os.path.expanduser(custom_command_file_path)
         if not file_name:
-            return
+            return False
         try:
             with open(file_name) as f:
                 data_file = f.read()
         except:
             data_file = None
         if not data_file:
-            return
+            return False
 
         try:
             custom_commands = json.loads(data_file)
             for json_object in custom_commands:
                 self.parse_custom_commands(json_object, menu)
+            return True
 
         except Exception:
             log.exception(
                 "Invalid custom command file %s. Exception:", data_file)
+            return False
 
     # function to build the custom commands menu and menuitems
     def parse_custom_commands(self, json_object, menu):
@@ -475,11 +499,11 @@ class Guake(SimpleGladeApp):
         log.info("Logging configuration complete")
         log.debug("Debug mode enabled")
 
-    def printDebug(self, text):
-        log.debug(text)
+    def printDebug(self, text, *args):
+        log.debug(text, *args)
 
-    def printInfo(self, text):
-        log.info(text)
+    def printInfo(self, text, *args):
+        log.info(text, *args)
 
     def set_background_transparency(self, transparency):
         for t in self.notebook.iter_terminals():
@@ -567,15 +591,27 @@ class Guake(SimpleGladeApp):
         screen = self.window.get_screen()
         x, y, _ = screen.get_root_window().get_pointer()
         screen_no = screen.get_monitor_at_point(x, y)
+        valignment = self.client.get_int(KEY('/general/window_valignment'))
 
         max_height = screen.get_monitor_geometry(screen_no).height
-        percent = y / (max_height / 100)
+        if valignment == ALIGN_BOTTOM:
+            percent = 100 * (max_height - y) / max_height
+        else:
+            percent = 100 * y / max_height
 
         if percent < 1:
             percent = 1
 
         window_rect = self.window.get_size()
-        self.window.resize(window_rect[0], y)
+        window_pos = self.window.get_position()
+        if valignment == ALIGN_BOTTOM:
+            self.window.resize(window_rect[0], max_height - y)
+            self.printDebug("Resizing on resizer drag to : %r, and moving to: %r",
+                            (window_rect[0], max_height - y), window_pos[0], y)
+            self.window.move(window_pos[0], y)
+        else:
+            self.window.resize(window_rect[0], y)
+            self.printDebug("Just moving on resizer drag to : %r", window_rect[0], y)
         self.client.set_int(KEY('/general/window_height'), int(percent))
         self.client.set_float(KEY('/general/window_height_f'), float(percent))
 
@@ -646,7 +682,11 @@ class Guake(SimpleGladeApp):
         link = self.getCurrentTerminalLinkUnderCursor()
         if link:
             self.get_widget('context_browse_on_web').set_visible(True)
-            self.get_widget('context_browse_on_web').set_label(_("Open Link: {}".format(link)))
+            if len(link) >= 28:
+                self.get_widget('context_browse_on_web').set_label(
+                    _("Open Link: '{}...'".format(link[:25])))
+            else:
+                self.get_widget('context_browse_on_web').set_label(_("Open Link: {}".format(link)))
             self.get_widget('separator_search').set_visible(True)
         else:
             self.get_widget('context_browse_on_web').set_label(_("Open Link..."))
@@ -780,8 +820,7 @@ class Guake(SimpleGladeApp):
         self.hidden = False
 
         # setting window in all desktops
-        if not self.is_fullscreen:
-            window_rect = self.set_final_window_rect()
+        window_rect = self.set_final_window_rect()
         self.get_widget('window-root').stick()
 
         # add tab must be called before window.show to avoid a
@@ -802,9 +841,12 @@ class Guake(SimpleGladeApp):
                 if isinstance(tab, gtk.RadioButton):
                     tab.modify_bg(gtk.STATE_ACTIVE, gtk.gdk.Color(str(self.selected_color)))
 
+        # move the window even when in fullscreen-mode
+        self.printDebug("Moving window to: %r", window_rect)
+        self.window.move(window_rect.x, window_rect.y)
+
         # this work arround an issue in fluxbox
         if not self.is_fullscreen:
-            self.window.move(window_rect.x, window_rect.y)
             self.client.notify(KEY('/general/window_height'))
 
         try:
@@ -831,10 +873,8 @@ class Guake(SimpleGladeApp):
         #         self.get_widget('window-root').get_urgency_hint()))
         #     glib.timeout_add_seconds(1, lambda: self.timeout_restore(time))
         #
-        log.debug("Current window geometry: %r",
-                  self.window.window.get_geometry())
 
-        log.debug("order to present and deiconify")
+        self.printDebug("order to present and deiconify")
         self.window.present()
         self.window.deiconify()
         self.window.window.deiconify()
@@ -854,6 +894,8 @@ class Guake(SimpleGladeApp):
         self.client.notify(KEY('/style/font/color'))
         self.client.notify(KEY('/style/background/color'))
 
+        self.printDebug("Current window position: %r", self.window.get_position())
+
     def hide_from_remote(self):
         """
         Hides the main window of the terminal and sets the visible
@@ -940,18 +982,22 @@ class Guake(SimpleGladeApp):
         halignment = self.client.get_int(KEY('/general/window_halignment'))
         valignment = self.client.get_int(KEY('/general/window_valignment'))
 
-        log.debug("set_final_window_rect")
-        log.debug("height_percents = %s", height_percents)
-        log.debug("width_percents = %s", width_percents)
-        log.debug("halignment = %s", halignment)
-        log.debug("valignment = %s", valignment)
+        self.printDebug("set_final_window_rect")
+        self.printDebug("  height_percents = %s", height_percents)
+        self.printDebug("  width_percents = %s", width_percents)
+        self.printDebug("  halignment = %s", halignment)
+        self.printDebug("  valignment = %s", valignment)
 
         # get the rectangle just from the destination monitor
         screen = self.window.get_screen()
         monitor = self.get_final_window_monitor()
         window_rect = screen.get_monitor_geometry(monitor)
-        log.debug("Current screen geometry: %r", window_rect)
-        log.debug("is unity: %s", self.is_using_unity())
+        self.printDebug("Current monitor geometry")
+        self.printDebug("  window_rect.x: %s", window_rect.x)
+        self.printDebug("  window_rect.y: %s", window_rect.y)
+        self.printDebug("  window_rect.height: %s", window_rect.height)
+        self.printDebug("  window_rect.width: %s", window_rect.width)
+        self.printDebug("is unity: %s", self.is_using_unity())
 
         if self.is_using_unity():
 
@@ -985,54 +1031,65 @@ class Guake(SimpleGladeApp):
 
             # launcher_hide_mode = 1 => autohide
             if unity_hide != 1:
-                log.debug("correcting window width because of launcher width %s "
-                          "(from %s to %s)",
-                          unity_dock,
-                          window_rect.width,
-                          window_rect.width - unity_dock)
+                self.printDebug("correcting window width because of launcher width %s "
+                                "(from %s to %s)",
+                                unity_dock,
+                                window_rect.width,
+                                window_rect.width - unity_dock)
 
                 window_rect.width = window_rect.width - unity_dock
 
         total_width = window_rect.width
         total_height = window_rect.height
 
-        # log.debug("total_width", total_width)
-        # log.debug("total_height", total_height)
+        self.printDebug("Correcteed monitor size:")
+        self.printDebug("  total_width: %s", total_width)
+        self.printDebug("  total_height: %s", total_height)
 
-        window_rect.height = window_rect.height * height_percents / 100
-        window_rect.width = window_rect.width * width_percents / 100
-
-        log.debug("BEFORE SETTINGS APPLICATION")
-        log.debug("window_rect.x: %s", window_rect.x)
-        log.debug("window_rect.y: %s", window_rect.y)
-        log.debug("window_rect.height: %s", window_rect.height)
-        log.debug("window_rect.width: %s", window_rect.width)
+        window_rect.height = int(float(window_rect.height) * float(height_percents) / 100.0)
+        window_rect.width = int(float(window_rect.width) * float(width_percents) / 100.0)
 
         if window_rect.width < total_width:
             if halignment == ALIGN_CENTER:
-                # log.debug("aligning to center!")
+                # self.printDebug("aligning to center!")
                 window_rect.x += (total_width - window_rect.width) / 2
             elif halignment == ALIGN_LEFT:
-                # log.debug("aligning to left!")
+                # self.printDebug("aligning to left!")
                 window_rect.x += 0
             elif halignment == ALIGN_RIGHT:
-                # log.debug("aligning to right!")
+                # self.printDebug("aligning to right!")
                 window_rect.x += total_width - window_rect.width
         if window_rect.height < total_height:
             if valignment == ALIGN_BOTTOM:
                 window_rect.y += (total_height - window_rect.height)
 
-        log.debug("RESIZING MAIN WINDOW TO THE FOLLOWING VALUES:")
-        log.debug("window_rect.x: %s", window_rect.x)
-        log.debug("window_rect.y: %s", window_rect.y)
-        log.debug("window_rect.height: %s", window_rect.height)
-        log.debug("window_rect.width: %s", window_rect.width)
-
-        self.window.resize(window_rect.width, window_rect.height)
-        self.window.move(window_rect.x, window_rect.y)
+        if width_percents == 100 and height_percents == 100:
+            self.printDebug("MAXIMIZING MAIN WINDOW")
+            self.window.maximize()
+        else:
+            self.printDebug("RESIZING MAIN WINDOW TO THE FOLLOWING VALUES:")
+            self.window.unmaximize()
+            self.printDebug("  window_rect.x: %s", window_rect.x)
+            self.printDebug("  window_rect.y: %s", window_rect.y)
+            self.printDebug("  window_rect.height: %s", window_rect.height)
+            self.printDebug("  window_rect.width: %s", window_rect.width)
+            # Note: move_resize is only on GTK3
+            self.window.resize(window_rect.width, window_rect.height)
+            self.window.move(window_rect.x, window_rect.y)
+            self.window.move(window_rect.x, window_rect.y)
+            self.printDebug("Updated window position: %r", self.window.get_position())
 
         return window_rect
 
+    def force_move_if_shown(self):
+        if not self.hidden:
+            # when displayed, GTK might refuse to move the window (X or Y position). Just hide and
+            # redisplay it so the final position is correct
+            self.printDebug("FORCING HIDE")
+            self.hide()
+            self.printDebug("FORCING SHOW")
+            self.show()
+
     # -- configuration --
 
     def load_config(self):
@@ -1052,6 +1109,7 @@ class Guake(SimpleGladeApp):
         self.client.notify(KEY('/general/history_size'))
         self.client.notify(KEY('/general/show_resizer'))
         self.client.notify(KEY('/general/use_vte_titles'))
+        self.client.notify(KEY('/general/abbreviate_tab_names'))
         self.client.notify(KEY('/general/max_tab_name_length'))
         self.client.notify(KEY('/general/quick_open_enable'))
         self.client.notify(KEY('/general/quick_open_command_line'))
@@ -1315,19 +1373,49 @@ class Guake(SimpleGladeApp):
             libutempter.utempter_remove_record(term.get_pty())
         self.delete_tab(self.notebook.page_num(widget), kill=False)
 
+    def recompute_tabs_titles(self):
+        """Updates labels on all tabs. This is required when `self.abbreviate`
+        changes
+        """
+        use_vte_titles = self.client.get_bool(KEY("/general/use_vte_titles"))
+        if not use_vte_titles:
+            return
+
+        for tab, vte in zip(self.tabs.get_children(), self.notebook.term_list):
+            tab.set_label(self.compute_tab_title(vte))
+
+    def compute_tab_title(self, vte):
+        """Abbreviate and cut vte terminal title when necessary
+        """
+        vte_title = vte.get_window_title() or _("Terminal")
+        try:
+            current_directory = vte.get_current_directory()
+            if self.abbreviate and vte_title.endswith(current_directory):
+                parts = current_directory.split('/')
+                parts = list(map(lambda s: s[:1], parts[:-1])) + [parts[-1]]
+                vte_title = vte_title[:len(vte_title) - len(current_directory)] + '/'.join(parts)
+        except OSError:
+            pass
+        return self._shorten_tab_title(vte_title)
+
+    def _shorten_tab_title(self, text):
+        use_vte_titles = self.client.get_bool(KEY("/general/use_vte_titles"))
+        if not use_vte_titles:
+            return text
+        max_name_length = self.client.get_int(KEY("/general/max_tab_name_length"))
+        if max_name_length != 0 and len(text) > max_name_length:
+            text = "..." + text[-max_name_length:]
+        return text
+
     def on_terminal_title_changed(self, vte, box):
-        use_them = self.client.get_bool(KEY("/general/use_vte_titles"))
-        if not use_them:
+        use_vte_titles = self.client.get_bool(KEY("/general/use_vte_titles"))
+        if not use_vte_titles:
             return
         page = self.notebook.page_num(box)
         tab = self.tabs.get_children()[page]
         # if tab has been renamed by user, don't override.
         if not getattr(tab, 'custom_label_set', False):
-            vte_title = vte.get_window_title()
-            max_name_length = self.client.get_int(KEY("/general/max_tab_name_length"))
-            if len(vte_title) > max_name_length and max_name_length is not 0:
-                vte_title = vte_title[:max_name_length]
-            tab.set_label(vte_title)
+            tab.set_label(self.compute_tab_title(vte))
 
     def on_rename_current_tab_activate(self, *args):
         """Shows a dialog to rename the current tab.
@@ -1361,10 +1449,8 @@ class Guake(SimpleGladeApp):
         self.preventHide = False
 
         if response == gtk.RESPONSE_ACCEPT:
-            max_name_length = self.client.get_int(KEY("/general/max_tab_name_length"))
             new_text = entry.get_text()
-            if len(new_text) > max_name_length and max_name_length is not 0:
-                new_text = new_text[:max_name_length]
+            new_text = self._shorten_tab_title(new_text)
 
             self.selected_tab.set_label(new_text)
             # if user sets empty name, consider he wants default behavior.
@@ -1610,7 +1696,7 @@ class Guake(SimpleGladeApp):
         box.terminal.pid = pid
 
         # Adding a new radio button to the tabbar
-        label = box.terminal.get_window_title() or _("Terminal")
+        label = self.compute_tab_title(box.terminal)
         tabs = self.tabs.get_children()
         parent = tabs and tabs[0] or None
         bnt = gtk.RadioButton(group=parent, label=label, use_underline=False)
@@ -1740,6 +1826,10 @@ class Guake(SimpleGladeApp):
         self.tabs.reorder_child(self.tabs.get_children()[old_tab_pos], new_tab_pos)
         self.notebook.set_current_page(new_tab_pos)
 
+    def is_tabs_scrollbar_visible(self):
+        return (self.window.get_visible() and
+                self.get_widget('tabs-scrolledwindow').get_hscrollbar().get_visible())
+
     def delete_tab(self, pagepos, kill=True):
         """This function will destroy the notebook page, terminal and
         tab widgets and will call the function to kill interpreter
@@ -1762,6 +1852,12 @@ class Guake(SimpleGladeApp):
         else:
             self.set_terminal_focus()
 
+        self.was_deleted_tab = True
+        abbreviate_tab_names = self.client.get_bool(KEY('/general/abbreviate_tab_names'))
+        if abbreviate_tab_names and not self.is_tabs_scrollbar_visible():
+            self.abbreviate = False
+            self.recompute_tabs_titles()
+
     def set_terminal_focus(self):
         """Grabs the focus on the current tab.
         """
@@ -1835,7 +1931,14 @@ class Guake(SimpleGladeApp):
             self.mainframe.reorder_child(self.notebook, 2)
         else:
             self.mainframe.reorder_child(self.notebook, 0)
-        self.mainframe.pack_start(self.notebook, expand=True, fill=True, padding=0)
+
+        # make sure resizer is at right position depending on window alignment
+        if self.client.get_int(KEY('/general/window_valignment')) == ALIGN_BOTTOM:
+            self.mainframe.reorder_child(self.resizer, 0)
+        else:
+            self.mainframe.reorder_child(self.resizer, -1)
+
+        # self.mainframe.pack_start(self.notebook, expand=True, fill=True, padding=0)
 
     def reset_terminal(self, directory=None):
         self.preventHide = True
