@@ -72,92 +72,92 @@ ERASE_BINDINGS = {'ASCII DEL': 'ascii-delete',
                   'Control-H': 'ascii-backspace'}
 
 HOTKEYS = [
-    {'label': 'General',
+    {'label': _('General'),
      'keys': [{'key': GKEY('show_hide'),
-               'label': 'Toggle Guake visibility'},
+               'label': _('Toggle Guake visibility')},
               {'key': LKEY('toggle_fullscreen'),
-               'label': 'Toggle Fullscreen'},
+               'label': _('Toggle Fullscreen')},
               {'key': LKEY('toggle_hide_on_lose_focus'),
-               'label': 'Toggle Hide on Lose Focus'},
+               'label': _('Toggle Hide on Lose Focus')},
               {'key': LKEY('quit'),
-               'label': 'Quit'},
+               'label': _('Quit')},
               {'key': LKEY('reset_terminal'),
-               'label': 'Reset terminal'},
+               'label': _('Reset terminal')},
               ]},
 
-    {'label': 'Tab management',
+    {'label': _('Tab management'),
      'keys': [{'key': LKEY('new_tab'),
-               'label': 'New tab'},
+               'label': _('New tab')},
               {'key': LKEY('close_tab'),
-               'label': 'Close tab'},
+               'label': _('Close tab')},
               {'key': LKEY('rename_current_tab'),
-               'label': 'Rename current tab'},
+               'label': _('Rename current tab')},
               ]},
 
-    {'label': 'Navigation',
+    {'label': _('Navigation'),
      'keys': [{'key': LKEY('previous_tab'),
-               'label': 'Go to previous tab'},
+               'label': _('Go to previous tab')},
               {'key': LKEY('next_tab'),
-               'label': 'Go to next tab'},
+               'label': _('Go to next tab')},
               {'key': LKEY('move_tab_left'),
-               'label': 'Move current tab left'},
+               'label': _('Move current tab left')},
               {'key': LKEY('move_tab_right'),
-               'label': 'Move current tab right'},
+               'label': _('Move current tab right')},
               {'key': LKEY('switch_tab1'),
-               'label': 'Go to first tab'},
+               'label': _('Go to first tab')},
               {'key': LKEY('switch_tab2'),
-               'label': 'Go to second tab'},
+               'label': _('Go to second tab')},
               {'key': LKEY('switch_tab3'),
-               'label': 'Go to third tab'},
+               'label': _('Go to third tab')},
               {'key': LKEY('switch_tab4'),
-               'label': 'Go to fourth tab'},
+               'label': _('Go to fourth tab')},
               {'key': LKEY('switch_tab5'),
-               'label': 'Go to fifth tab'},
+               'label': _('Go to fifth tab')},
               {'key': LKEY('switch_tab6'),
-               'label': 'Go to sixth tab'},
+               'label': _('Go to sixth tab')},
               {'key': LKEY('switch_tab7'),
-               'label': 'Go to seventh tab'},
+               'label': _('Go to seventh tab')},
               {'key': LKEY('switch_tab8'),
-               'label': 'Go to eighth tab'},
+               'label': _('Go to eighth tab')},
               {'key': LKEY('switch_tab9'),
-               'label': 'Go to ninth tab'},
+               'label': _('Go to ninth tab')},
               {'key': LKEY('switch_tab10'),
-               'label': 'Go to tenth tab'},
+               'label': _('Go to tenth tab')},
               {'key': LKEY('switch_tab_last'),
-               'label': 'Go to last tab'},
+               'label': _('Go to last tab')},
               ]},
 
-    {'label': 'Appearance',
+    {'label': _('Appearance'),
      'keys': [{'key': LKEY('zoom_out'),
-               'label': 'Zoom out'},
+               'label': _('Zoom out')},
               {'key': LKEY('zoom_in'),
-               'label': 'Zoom in'},
+               'label': _('Zoom in')},
               {'key': LKEY('zoom_in_alt'),
-               'label': 'Zoom in (alternative)'},
+               'label': _('Zoom in (alternative)')},
               {'key': LKEY('increase_height'),
-               'label': 'Increase height'},
+               'label': _('Increase height')},
               {'key': LKEY('decrease_height'),
-               'label': 'Decrease height'},
+               'label': _('Decrease height')},
               {'key': LKEY('increase_transparency'),
-               'label': 'Increase transparency'},
+               'label': _('Increase transparency')},
               {'key': LKEY('decrease_transparency'),
-               'label': 'Decrease transparency'},
+               'label': _('Decrease transparency')},
               {'key': LKEY('toggle_transparency'),
-               'label': 'Toggle transparency'}
+               'label': _('Toggle transparency')}
               ]},
 
-    {'label': 'Clipboard',
+    {'label': _('Clipboard'),
      'keys': [{'key': LKEY('clipboard_copy'),
-               'label': 'Copy text to clipboard'},
+               'label': _('Copy text to clipboard')},
               {'key': LKEY('clipboard_paste'),
-               'label': 'Paste text from clipboard'},
+               'label': _('Paste text from clipboard')},
               ]},
 
-    {'label': 'Extra features',
+    {'label': _('Extra features'),
      'keys': [
-              {'key': LKEY('search_on_web'),
-               'label': 'Search select text on web'},
-     ]},
+        {'key': LKEY('search_on_web'),
+         'label': _('Search select text on web')},
+    ]},
 ]
 
 
@@ -166,8 +166,9 @@ class PrefsCallbacks(object):
     """Holds callbacks that will be used in the PrefsDialg class.
     """
 
-    def __init__(self):
+    def __init__(self, prefDlg):
         self.client = gconf.client_get_default()
+        self.prefDlg = prefDlg
 
     # general tab
 
@@ -259,11 +260,17 @@ class PrefsCallbacks(object):
         """
         self.client.set_bool(KEY('/general/use_vte_titles'), chk.get_active())
 
+    def on_abbreviate_tab_names_toggled(self, chk):
+        """Save `abbreviate_tab_names` property value in gconf
+        """
+        self.client.set_bool(KEY('/general/abbreviate_tab_names'), chk.get_active())
+
     def on_max_tab_name_length_changed(self, spin):
         """Changes the value of max_tab_name_length in gconf
         """
         val = int(spin.get_value())
         self.client.set_int(KEY('/general/max_tab_name_length'), val)
+        self.prefDlg.update_vte_subwidgets_states()
 
     def on_mouse_display_toggled(self, chk):
         """Set the 'appear on mouse display' preference in gconf. This
@@ -439,10 +446,13 @@ class PrefsDialog(SimpleGladeApp):
         """
         super(PrefsDialog, self).__init__(gladefile('prefs.glade'),
                                           root='config-window')
-        self.add_callbacks(PrefsCallbacks())
+        self.add_callbacks(PrefsCallbacks(self))
 
         self.client = gconf.client_get_default()
 
+        # window cleanup handler
+        self.get_widget('config-window').connect('destroy', self.on_destroy)
+
         # setting evtbox title bg
         eventbox = self.get_widget('eventbox-title')
         eventbox.modify_bg(gtk.STATE_NORMAL,
@@ -522,6 +532,10 @@ class PrefsDialog(SimpleGladeApp):
         """
         self.get_widget('config-window').hide()
 
+    def on_destroy(self, window):
+        self.demo_terminal.kill()
+        self.demo_terminal.destroy()
+
     def update_preview(self, file_chooser, preview):
         """Used by filechooser to preview image files
         """
@@ -572,6 +586,18 @@ class PrefsDialog(SimpleGladeApp):
         self.get_widget('quick_open_command_line').set_sensitive(chk.get_active())
         self.get_widget('quick_open_in_current_terminal').set_sensitive(chk.get_active())
 
+    def toggle_use_vte_titles(self, chk):
+        """When vte titles aren't used, there is nothing to abbreviate
+        """
+        self.update_vte_subwidgets_states()
+
+    def update_vte_subwidgets_states(self):
+        do_use_vte_titles = self.get_widget('use_vte_titles').get_active()
+        max_tab_name_length_wdg = self.get_widget('max_tab_name_length')
+        max_tab_name_length_wdg.set_sensitive(do_use_vte_titles)
+        self.get_widget('lbl_max_tab_name_length').set_sensitive(do_use_vte_titles)
+        self.get_widget('abbreviate_tab_names').set_sensitive(do_use_vte_titles)
+
     def clear_background_image(self, btn):
         """Unset the gconf variable that holds the name of the
         background image of all terminals.
@@ -750,10 +776,17 @@ class PrefsDialog(SimpleGladeApp):
         value = self.client.get_bool(KEY('/general/use_vte_titles'))
         self.get_widget('use_vte_titles').set_active(value)
 
+        # abbreviate tab names
+        self.get_widget('abbreviate_tab_names').set_sensitive(value)
+        value = self.client.get_bool(KEY('/general/abbreviate_tab_names'))
+        self.get_widget('abbreviate_tab_names').set_active(value)
+
         # max tab name length
         value = self.client.get_int(KEY('/general/max_tab_name_length'))
         self.get_widget('max_tab_name_length').set_value(value)
 
+        self.update_vte_subwidgets_states()
+
         value = self.client.get_float(KEY('/general/window_height_f'))
         if not value:
             value = self.client.get_int(KEY('/general/window_height'))
